![create-nuxt-app](https://user-images.githubusercontent.com/904724/85284101-daf3fc00-b48e-11ea-93e2-8a9df49153c1.png)

# Create Nuxt App

[![NPM version](https://img.shields.io/npm/v/create-nuxt-app.svg?style=flat)](https://npmjs.com/package/create-nuxt-app)
[![NPM downloads](https://img.shields.io/npm/dm/create-nuxt-app.svg?style=flat)](https://npmjs.com/package/create-nuxt-app)
[![GitHub Action](https://github.com/nuxt/create-nuxt-app/workflows/ci/badge.svg?branch=master)](https://github.com/nuxt/create-nuxt-app/actions?query=branch%3Amaster++)

> Create a [Nuxt.js](https://nuxtjs.org) project in seconds

## Usage

Make sure you have [npx](https://www.npmjs.com/package/npx) installed (`npx` is shipped by default since [npm](https://www.npmjs.com/get-npm) `5.2.0`)

```bash
npx create-nuxt-app <my-project>
```

Or starting with npm v6.1 you can do:

```bash
npm init nuxt-app <my-project>
```

Or with [yarn](https://yarnpkg.com/en/):

```bash
yarn create nuxt-app <my-project>
```

## Features :tada:

1. Package manager
    - Yarn
    - Npm
1. Programming language
    - JavaScript
    - TypeScript
1. UI framework:
    - None (feel free to add one later)
    - [Ant Design Vue](https://github.com/vueComponent/ant-design-vue)
    - [Bootstrap](https://github.com/bootstrap-vue/bootstrap-vue)
    - [Buefy](https://buefy.org)
    - [Bulma](https://github.com/jgthms/bulma)
    - [Chakra UI](https://github.com/chakra-ui/chakra-ui-vue)
    - [Element](https://github.com/ElemeFE/element)
    - [Framevuerk](https://github.com/framevuerk/framevuerk)
    - [iView](https://www.iviewui.com/)
    - [Tachyons](https://github.com/tachyons-css/tachyons)
    - [Tailwind CSS](https://github.com/tailwindcss/tailwindcss)
    - [Vuesax](https://github.com/lusaxweb/vuesax)
    - [Vuetify](https://github.com/vuetifyjs/vuetify)
1. Nuxt.js modules:
    - [Axios](https://github.com/nuxt-community/axios-module)
    - [Progressive Web App (PWA)](https://github.com/nuxt-community/pwa-module)
    - [Content](https://github.com/nuxt/content)
1. Linting tools:
    - [ESLint](https://github.com/nuxt/eslint-config)
    - [Prettier](https://github.com/prettier/prettier)
    - [Lint staged files](https://github.com/okonet/lint-staged)
    - [StyleLint](https://github.com/stylelint/stylelint)
1. Testing framework:
    - None
    - [Jest](https://github.com/facebook/jest)
    - [AVA](https://github.com/avajs/ava)
    - [WebdriverIO](https://webdriver.io)
1. Rendering mode
    - [Universal (SSR / Static)](https://nuxtjs.org/guide/#server-rendered-universal-ssr-)
    - [SPA](https://nuxtjs.org/guide/#single-page-applications-spa-)
1. Deployment target
    - [Server (Node.js hosting)](https://nuxtjs.org/api/configuration-target)
    - [Static (Static/JAMStack hosting)](https://nuxtjs.org/api/configuration-target)
1. Development tools
    - [jsconfig.json](https://code.visualstudio.com/docs/languages/jsconfig)
    - [Semantic PR](https://probot.github.io/apps/semantic-pull-requests/)

## CLI Options

### `--edge`

Alias: `-e`.

To install [nuxt-edge](https://www.npmjs.com/package/nuxt-edge) instead of [nuxt](https://www.npmjs.com/package/nuxt), add the command line option `--edge`:

```bash
npx create-nuxt-app <my-project> --edge
```

Or

```bash
npm init nuxt-app <my-project> --edge
```

Or

```bash
yarn create nuxt-app <my-project> --edge
```

### `--info`

Alias: `-i`. Print out debugging information relating to the local environment and exit.

### `--help`

Alias: `-h`. Show the help information and exit, include: usage, command and all cli options.

### `--verbose`

Show debug logs

### `--version`

Alias: `-v`. Show version number and exit.

## Credits

- [egoist](https://github.com/egoist)
- [clarko](https://github.com/clarkdo)
- All our contributors ([list](https://github.com/nuxt/create-nuxt-app/contributors)).
